summaryrefslogtreecommitdiffstats
path: root/pts-core/modules
diff options
context:
space:
mode:
authorMichael Larabel <michael@phx-laptop.(none)>2008-08-19 21:08:24 -0400
committerMichael Larabel <michael@phx-laptop.(none)>2008-08-19 21:08:24 -0400
commita514b9ebdeead92da0f64715509249f80ddb1825 (patch)
tree787529624636050ee1ff4b7a72936739fbd71e35 /pts-core/modules
parent53631ac29e92253b5cf17033be6966195773fc87 (diff)
downloadphoronix-test-suite-upstream-a514b9ebdeead92da0f64715509249f80ddb1825.tar.gz
phoronix-test-suite-upstream-a514b9ebdeead92da0f64715509249f80ddb1825.tar.xz
phoronix-test-suite-upstream-a514b9ebdeead92da0f64715509249f80ddb1825.zip
graphics_override: Switch when !IS_ATI_GRAPHICS && !IS_NVIDIA_GRAPHICS
to use the PTS_MODULE_UNLOAD return.
Diffstat (limited to 'pts-core/modules')
-rw-r--r--pts-core/modules/graphics_override.php6
1 files changed, 1 insertions, 5 deletions
diff --git a/pts-core/modules/graphics_override.php b/pts-core/modules/graphics_override.php
index d2562dc..81d5964 100644
--- a/pts-core/modules/graphics_override.php
+++ b/pts-core/modules/graphics_override.php
@@ -43,7 +43,7 @@ class graphics_override extends pts_module_interface
if(!(IS_NVIDIA_GRAPHICS || IS_ATI_GRAPHICS))
{
echo "\nNo supported driver found for graphics_override module!\n";
- return; // Not using a supported driver
+ return PTS_MODULE_UNLOAD; // Not using a supported driver, quit the module
}
$force_aa = trim(getenv("FORCE_AA"));
@@ -152,10 +152,6 @@ class graphics_override extends pts_module_interface
}
public static function __shutdown()
{
- if(!(IS_NVIDIA_GRAPHICS || IS_ATI_GRAPHICS))
- {
- return; // Not using a supported driver
- }
if(IS_NVIDIA_GRAPHICS)
{